@@ -19,18 +19,3 @@ impl BinPaths {
         Ok(())
     }
 }
-
-#[cfg(test)]
-mod tests {
-    use crate::test::reset;
-
-    #[test]
-    fn test_bin_paths() {
-        reset();
-        assert_cli!("i");
-        assert_cli_snapshot!("bin-paths", @r"
-        ~/data/installs/tiny/3.1.0/bin
-        ~/data/installs/dummy/ref-master/bin
-        ");
-    }
-}
