@@ -7,11 +7,11 @@ use path_absolutize::Absolutize;
 
 use crate::cli::args::{BackendArg, ToolArg};
 use crate::config::config_file::ConfigFile;
-use crate::config::{config_file, is_global_config, Config, LOCAL_CONFIG_FILENAMES, SETTINGS};
+use crate::config::{config_file, is_global_config, Config, SETTINGS};
 use crate::env::{
     MISE_DEFAULT_CONFIG_FILENAME, MISE_DEFAULT_TOOL_VERSIONS_FILENAME, MISE_GLOBAL_CONFIG_FILE,
 };
-use crate::file::{display_path, FindUp};
+use crate::file::display_path;
 use crate::toolset::{
     InstallOptions, ResolveOptions, ToolRequest, ToolSource, ToolVersion, ToolsetBuilder,
 };
@@ -23,6 +23,12 @@ use crate::{config, env, file};
 /// This will install the tool version if it is not already installed.
 /// By default, this will use a `mise.toml` file in the current directory.
 ///
+/// In the following order:
+///   - If `MISE_DEFAULT_CONFIG_FILENAME` is set, it will use that instead.
+///   - If `MISE_OVERRIDE_CONFIG_FILENAMES` is set, it will the first from that list.
+///   - If `MISE_ENV` is set, it will use a `mise.<env>.toml` instead.
+///   - Otherwise just "mise.toml"
+///
 /// Use the `--global` flag to use the global config file instead.
 #[derive(Debug, clap::Args)]
 #[clap(verbatim_doc_comment, visible_alias = "u", after_long_help = AFTER_LONG_HELP)]
@@ -185,7 +191,7 @@ impl Use {
 
     fn get_config_file(&self) -> Result<Box<dyn ConfigFile>> {
         let cwd = env::current_dir()?;
-        let path = if let Some(env) = &*env::MISE_PROFILE {
+        let path = if let Some(env) = &*env::MISE_ENV {
             config_file_from_dir(&cwd.join(format!("mise.{env}.toml")))
         } else if self.global || env::in_home_dir() {
             MISE_GLOBAL_CONFIG_FILE.clone()
@@ -244,13 +250,11 @@ fn config_file_from_dir(p: &Path) -> PathBuf {
     if !p.is_dir() {
         return p.to_path_buf();
     }
-    let filenames = LOCAL_CONFIG_FILENAMES
-        .iter()
-        .map(|f| f.to_string())
-        .collect::<Vec<_>>();
-    for p in FindUp::new(p, &filenames) {
-        if !is_global_config(&p) {
-            return p;
+    for dir in file::all_dirs().unwrap_or_default() {
+        if let Some(cf) = config::config_files_in_dir(&dir).last() {
+            if !is_global_config(cf) {
+                return cf.clone();
+            }
         }
     }
     match SETTINGS.asdf_compat {
