@@ -84,46 +84,3 @@ static AFTER_LONG_HELP: &str = color_print::cstr!(
     20.0.0
 "#
 );
-
-#[cfg(test)]
-mod tests {
-    use crate::test::reset;
-    use test_log::test;
-
-    #[test]
-    fn test_which() {
-        reset();
-        assert_cli!("use", "dummy@1.0.0");
-        assert_cli_snapshot!("which", "dummy");
-        assert_cli!("use", "dummy@ref:master");
-        assert_cli!("uninstall", "dummy@1.0.0");
-        assert_cli!("use", "--rm", "dummy");
-    }
-
-    #[test]
-    fn test_which_plugin() {
-        reset();
-        assert_cli!("use", "dummy@1.0.0");
-        assert_cli_snapshot!("which", "--plugin", "dummy");
-        assert_cli!("use", "dummy@ref:master");
-        assert_cli!("uninstall", "dummy@1.0.0");
-        assert_cli!("use", "--rm", "dummy");
-    }
-
-    #[test]
-    fn test_which_version() {
-        reset();
-        assert_cli!("use", "dummy@1.0.0");
-        assert_cli_snapshot!("which", "--version", "dummy");
-        assert_cli!("use", "dummy@ref:master");
-        assert_cli!("uninstall", "dummy@1.0.0");
-        assert_cli!("use", "--rm", "dummy");
-    }
-
-    #[test]
-    fn test_which_tool() {
-        reset();
-        assert_cli!("install", "dummy@1.0.1");
-        assert_cli_snapshot!("which", "dummy", "--tool=dummy@1.0.1");
-    }
-}
