@@ -247,8 +247,8 @@ impl<'a> CmdLineRunner<'a> {
         self.pr = Some(pr);
         self
     }
-    pub fn with_raw(&mut self) -> &mut Self {
-        self.raw = true;
+    pub fn raw(mut self, raw: bool) -> Self {
+        self.raw = raw;
         self
     }
 
@@ -458,6 +458,7 @@ enum ChildProcessOutput {
 }
 
 #[cfg(test)]
+#[cfg(unix)]
 mod tests {
     use pretty_assertions::assert_eq;
 
