@@ -1,20 +1,20 @@
-use std::collections::{BTreeMap, BTreeSet, HashMap};
-use std::fmt::{Debug, Formatter};
-use std::iter::once;
-use std::path::{Path, PathBuf};
-use std::sync::{Arc, OnceLock, RwLock};
-
 use eyre::{ensure, eyre, Context, Result};
-use indexmap::IndexMap;
+use indexmap::{IndexMap, IndexSet};
 use itertools::Itertools;
 use once_cell::sync::{Lazy, OnceCell};
 use rayon::prelude::*;
 pub use settings::Settings;
+use std::collections::{BTreeMap, BTreeSet, HashMap};
+use std::fmt::{Debug, Formatter};
+use std::iter::once;
+use std::path::{Path, PathBuf};
+use std::sync::{Arc, Mutex, OnceLock, RwLock};
+use std::time::Duration;
 use walkdir::WalkDir;
 
 use crate::backend::ABackend;
 use crate::cli::version;
-use crate::config::config_file::legacy_version::LegacyVersionFile;
+use crate::config::config_file::idiomatic_version::IdiomaticVersionFile;
 use crate::config::config_file::mise_toml::{MiseToml, Tasks};
 use crate::config::config_file::ConfigFile;
 use crate::config::env_directive::EnvResults;
@@ -26,14 +26,17 @@ use crate::toolset::{
     install_state, ToolRequestSet, ToolRequestSetBuilder, ToolVersion, Toolset, ToolsetBuilder,
 };
 use crate::ui::style;
-use crate::{backend, dirs, env, file, lockfile, registry, runtime_symlinks, shims};
+use crate::{backend, dirs, env, file, lockfile, registry, runtime_symlinks, shims, timeout};
 
 pub mod config_file;
 pub mod env_directive;
 pub mod settings;
 pub mod tracking;
 
+use crate::hook_env::WatchFilePattern;
+use crate::hooks::Hook;
 use crate::plugins::PluginType;
+use crate::watch_files::WatchFile;
 pub use settings::SETTINGS;
 
 type AliasMap = IndexMap<String, Alias>;
@@ -62,7 +65,6 @@ pub struct Alias {
     pub versions: IndexMap<String, String>,
 }
 
-pub static CONFIG: Lazy<Arc<Config>> = Lazy::new(Config::get);
 static _CONFIG: RwLock<Option<Arc<Config>>> = RwLock::new(None);
 
 pub fn is_loaded() -> bool {
@@ -82,10 +84,11 @@ impl Config {
         Ok(config)
     }
     pub fn load() -> Result<Self> {
+        reset();
         time!("load start");
-        let legacy_files = load_legacy_files();
-        time!("load legacy_files");
-        let config_filenames = legacy_files
+        let idiomatic_files = load_idiomatic_files();
+        time!("load idiomatic_files");
+        let config_filenames = idiomatic_files
             .keys()
             .chain(DEFAULT_CONFIG_FILENAMES.iter())
             .cloned()
@@ -94,7 +97,7 @@ impl Config {
         let config_paths = load_config_paths(&config_filenames, false);
         time!("load config_paths");
         trace!("config_paths: {config_paths:?}");
-        let config_files = load_all_config_files(&config_paths, &legacy_files)?;
+        let config_files = load_all_config_files(&config_paths, &idiomatic_files)?;
         time!("load config_files");
 
         let mut config = Self {
@@ -319,6 +322,7 @@ impl Config {
     pub fn task_includes_for_dir(&self, dir: &Path) -> Vec<PathBuf> {
         self.configs_at_root(dir)
             .iter()
+            .rev()
             .find_map(|cf| cf.task_config().includes.clone())
             .unwrap_or_else(default_task_includes)
             .into_par_iter()
@@ -344,11 +348,11 @@ impl Config {
                 p.is_file() && p.extension().unwrap_or_default().to_string_lossy() == "toml"
             })
             .map(|p| {
-                self.load_task_file(p).unwrap_or_else(|err| {
-                    warn!("loading tasks in {}: {err}", display_path(p));
-                    vec![]
-                })
+                self.load_task_file(p)
+                    .wrap_err_with(|| format!("loading tasks in {}", display_path(p)))
             })
+            .collect::<Result<Vec<_>>>()?
+            .into_iter()
             .flatten()
             .collect::<Vec<_>>();
         let file_tasks = includes
@@ -411,7 +415,7 @@ impl Config {
     }
 
     fn load_system_tasks(&self) -> Result<Vec<Task>> {
-        let cf = self.config_files.get(&dirs::SYSTEM.join("config.toml"));
+        let cf = self.config_files.get(&*env::MISE_SYSTEM_CONFIG_FILE);
         let config_root = cf
             .and_then(|cf| cf.project_root())
             .map(|p| p.to_path_buf())
@@ -423,7 +427,6 @@ impl Config {
             .collect())
     }
 
-    #[allow(clippy::borrowed_box)]
     fn load_config_tasks(&self, cf: &Option<&Box<dyn ConfigFile>>) -> Vec<Task> {
         cf.map(|cf| cf.tasks())
             .unwrap_or_default()
@@ -432,7 +435,6 @@ impl Config {
             .collect()
     }
 
-    #[allow(clippy::borrowed_box)]
     fn load_file_tasks(&self, cf: &Option<&Box<dyn ConfigFile>>, config_root: &Path) -> Vec<Task> {
         let includes = match cf {
             Some(cf) => cf
@@ -471,6 +473,7 @@ impl Config {
             .try_collect::<_, Vec<PathBuf>, _>()?
             .into_par_iter()
             .filter(|p| file::is_executable(p))
+            .filter(|p| !SETTINGS.task_disable_paths.iter().any(|d| p.starts_with(d)))
             .map(|path| Task::from_path(&path, root, config_root))
             .collect()
     }
@@ -553,22 +556,58 @@ impl Config {
         Ok(env_results)
     }
 
-    pub fn watch_files(&self) -> eyre::Result<BTreeSet<PathBuf>> {
-        let env_results = self.env_results()?;
+    pub fn hooks(&self) -> Result<Vec<(PathBuf, Hook)>> {
+        self.config_files
+            .values()
+            .map(|cf| Ok((cf.project_root(), cf.hooks()?)))
+            .filter_map_ok(|(root, hooks)| root.map(|r| (r.to_path_buf(), hooks)))
+            .map_ok(|(root, hooks)| {
+                hooks
+                    .into_iter()
+                    .map(|h| (root.clone(), h))
+                    .collect::<Vec<_>>()
+            })
+            .flatten_ok()
+            .collect()
+    }
+
+    pub fn watch_file_hooks(&self) -> Result<IndexSet<(PathBuf, WatchFile)>> {
         Ok(self
             .config_files
-            .keys()
-            .map(|p| p.to_path_buf())
-            .chain(env_results.env_files.clone())
-            .chain(env_results.env_scripts.clone())
-            .chain(SETTINGS.env_files())
+            .values()
+            .map(|cf| Ok((cf.project_root(), cf.watch_files()?)))
+            .collect::<Result<Vec<_>>>()?
+            .into_iter()
+            .filter_map(|(root, watch_files)| root.map(|r| (r.to_path_buf(), watch_files)))
+            .flat_map(|(root, watch_files)| {
+                watch_files
+                    .iter()
+                    .map(|wf| (root.clone(), wf.clone()))
+                    .collect::<Vec<_>>()
+            })
             .collect())
     }
 
-    #[cfg(test)]
-    pub fn reset() {
-        Settings::reset(None);
-        _CONFIG.write().unwrap().take();
+    pub fn watch_files(&self) -> Result<BTreeSet<WatchFilePattern>> {
+        let env_results = self.env_results()?;
+        Ok(self
+            .config_files
+            .iter()
+            .map(|(p, cf)| {
+                let mut watch_files: Vec<WatchFilePattern> = vec![p.as_path().into()];
+                watch_files.extend(cf.watch_files()?.iter().map(|wf| WatchFilePattern {
+                    root: cf.project_root().map(|pr| pr.to_path_buf()),
+                    patterns: wf.patterns.clone(),
+                }));
+                Ok(watch_files)
+            })
+            .collect::<Result<Vec<_>>>()?
+            .into_iter()
+            .flatten()
+            .chain(env_results.env_files.iter().map(|p| p.as_path().into()))
+            .chain(env_results.env_scripts.iter().map(|p| p.as_path().into()))
+            .chain(SETTINGS.env_files().iter().map(|p| p.as_path().into()))
+            .collect())
     }
 }
 
@@ -581,18 +620,18 @@ fn get_project_root(config_files: &ConfigMap) -> Option<PathBuf> {
     project_root
 }
 
-fn load_legacy_files() -> BTreeMap<String, Vec<String>> {
-    if !SETTINGS.legacy_version_file {
+fn load_idiomatic_files() -> BTreeMap<String, Vec<String>> {
+    if !SETTINGS.idiomatic_version_file {
         return BTreeMap::new();
     }
-    let legacy = backend::list()
+    let idiomatic = backend::list()
         .into_par_iter()
         .filter(|tool| {
             !SETTINGS
-                .legacy_version_file_disable_tools
+                .idiomatic_version_file_disable_tools
                 .contains(tool.id())
         })
-        .filter_map(|tool| match tool.legacy_filenames() {
+        .filter_map(|tool| match tool.idiomatic_filenames() {
             Ok(filenames) => Some(
                 filenames
                     .iter()
@@ -609,26 +648,42 @@ fn load_legacy_files() -> BTreeMap<String, Vec<String>> {
         .flatten()
         .collect::<Vec<(String, String)>>();
 
-    let mut legacy_filenames = BTreeMap::new();
-    for (filename, plugin) in legacy {
-        legacy_filenames
+    let mut idiomatic_filenames = BTreeMap::new();
+    for (filename, plugin) in idiomatic {
+        idiomatic_filenames
             .entry(filename)
             .or_insert_with(Vec::new)
             .push(plugin);
     }
-    legacy_filenames
+    idiomatic_filenames
 }
 
-pub static LOCAL_CONFIG_FILENAMES: Lazy<Vec<&'static str>> = Lazy::new(|| {
-    if *env::MISE_DEFAULT_CONFIG_FILENAME == "mise.toml" {
-        vec![
+static LOCAL_CONFIG_FILENAMES: Lazy<IndexSet<&'static str>> = Lazy::new(|| {
+    let mut paths: IndexSet<&'static str> = IndexSet::new();
+    if let Some(o) = &*env::MISE_OVERRIDE_TOOL_VERSIONS_FILENAMES {
+        paths.extend(o.iter().map(|s| s.as_str()));
+    } else {
+        paths.extend([
+            ".tool-versions",
             &*env::MISE_DEFAULT_TOOL_VERSIONS_FILENAME, // .tool-versions
+        ]);
+    }
+    if !env::MISE_OVERRIDE_CONFIG_FILENAMES.is_empty() {
+        paths.extend(
+            env::MISE_OVERRIDE_CONFIG_FILENAMES
+                .iter()
+                .map(|s| s.as_str()),
+        )
+    } else {
+        paths.extend([
+            ".config/mise/conf.d/*.toml",
             ".config/mise/config.toml",
             ".config/mise.toml",
             ".mise/config.toml",
             "mise/config.toml",
             ".mise/config.toml",
             ".rtx.toml",
+            "mise.toml",
             &*env::MISE_DEFAULT_CONFIG_FILENAME, // mise.toml
             ".mise.toml",
             ".config/mise/config.local.toml",
@@ -637,20 +692,17 @@ pub static LOCAL_CONFIG_FILENAMES: Lazy<Vec<&'static str>> = Lazy::new(|| {
             ".rtx.local.toml",
             "mise.local.toml",
             ".mise.local.toml",
-        ]
-    } else {
-        vec![
-            &*env::MISE_DEFAULT_TOOL_VERSIONS_FILENAME,
-            &*env::MISE_DEFAULT_CONFIG_FILENAME,
-        ]
+        ]);
     }
+
+    paths
 });
 pub static DEFAULT_CONFIG_FILENAMES: Lazy<Vec<String>> = Lazy::new(|| {
     let mut filenames = LOCAL_CONFIG_FILENAMES
         .iter()
         .map(|f| f.to_string())
         .collect_vec();
-    if let Some(env) = &*env::MISE_PROFILE {
+    if let Some(env) = &*env::MISE_ENV {
         filenames.push(format!(".config/mise/config.{env}.toml"));
         filenames.push(format!(".config/mise.{env}.toml"));
         filenames.push(format!("mise/config.{env}.toml"));
@@ -673,15 +725,54 @@ static TOML_CONFIG_FILENAMES: Lazy<Vec<String>> = Lazy::new(|| {
         .map(|s| s.to_string())
         .collect()
 });
+pub static ALL_CONFIG_FILES: Lazy<IndexSet<PathBuf>> = Lazy::new(|| {
+    load_config_paths(&DEFAULT_CONFIG_FILENAMES, false)
+        .into_iter()
+        .collect()
+});
+// pub static LOCAL_CONFIG_FILES: Lazy<Vec<PathBuf>> = Lazy::new(|| {
+//     ALL_CONFIG_FILES
+//         .iter()
+//         .filter(|cf| !is_global_config(cf))
+//         .cloned()
+//         .collect()
+// });
+
+type GlobResults = HashMap<(PathBuf, String), Vec<PathBuf>>;
+static GLOB_RESULTS: Lazy<Mutex<GlobResults>> = Lazy::new(Default::default);
+
+pub fn glob(dir: &Path, pattern: &str) -> Result<Vec<PathBuf>> {
+    let mut results = GLOB_RESULTS.lock().unwrap();
+    let key = (dir.to_path_buf(), pattern.to_string());
+    if let Some(glob) = results.get(&key) {
+        return Ok(glob.clone());
+    }
+    let paths = glob::glob(dir.join(pattern).to_string_lossy().as_ref())?
+        .filter_map(|p| p.ok())
+        .collect_vec();
+    results.insert(key, paths.clone());
+    Ok(paths)
+}
+
+pub fn config_files_in_dir(dir: &Path) -> IndexSet<PathBuf> {
+    DEFAULT_CONFIG_FILENAMES
+        .iter()
+        .flat_map(|f| glob(dir, f).unwrap_or_default())
+        .collect()
+}
 
 pub fn load_config_paths(config_filenames: &[String], include_ignored: bool) -> Vec<PathBuf> {
-    let mut config_files = Vec::new();
+    let dirs = file::all_dirs().unwrap_or_default();
 
-    // The current directory is not always available, e.g.
-    // when a directory was deleted or inside FUSE mounts.
-    if let Some(current_dir) = &*dirs::CWD {
-        config_files.extend(file::FindUp::new(current_dir, config_filenames));
-    };
+    let mut config_files = dirs
+        .iter()
+        .flat_map(|dir| {
+            config_filenames
+                .iter()
+                .rev()
+                .flat_map(|f| glob(dir, f).unwrap_or_default().into_iter().rev())
+        })
+        .collect_vec();
 
     config_files.extend(global_config_files());
     config_files.extend(system_config_files());
@@ -694,14 +785,18 @@ pub fn load_config_paths(config_filenames: &[String], include_ignored: bool) ->
 }
 
 pub fn is_global_config(path: &Path) -> bool {
-    global_config_files()
-        .iter()
-        .chain(system_config_files().iter())
-        .any(|p| p == path)
+    global_config_files().contains(path) || system_config_files().contains(path)
 }
 
-pub fn global_config_files() -> Vec<PathBuf> {
-    let mut config_files = vec![];
+static GLOBAL_CONFIG_FILES: Lazy<Mutex<Option<IndexSet<PathBuf>>>> = Lazy::new(Default::default);
+static SYSTEM_CONFIG_FILES: Lazy<Mutex<Option<IndexSet<PathBuf>>>> = Lazy::new(Default::default);
+
+pub fn global_config_files() -> IndexSet<PathBuf> {
+    let mut g = GLOBAL_CONFIG_FILES.lock().unwrap();
+    if let Some(g) = &*g {
+        return g.clone();
+    }
+    let mut config_files = IndexSet::new();
     if env::var_path("MISE_CONFIG_FILE").is_none()
         && env::var_path("MISE_GLOBAL_CONFIG_FILE").is_none()
         && !*env::MISE_USE_TOML
@@ -710,17 +805,17 @@ pub fn global_config_files() -> Vec<PathBuf> {
         // because that's how the user overrides the default
         let home_config = dirs::HOME.join(env::MISE_DEFAULT_TOOL_VERSIONS_FILENAME.as_str());
         if home_config.is_file() {
-            config_files.push(home_config);
+            config_files.insert(home_config);
         }
     };
     let global_config = env::MISE_GLOBAL_CONFIG_FILE.clone();
     let global_local_config = global_config.with_extension("local.toml");
     for f in [global_config, global_local_config] {
         if f.is_file() {
-            config_files.push(f);
+            config_files.insert(f);
         }
     }
-    if let Some(env) = &*env::MISE_PROFILE {
+    if let Some(env) = &*env::MISE_ENV {
         let global_profile_files = vec![
             dirs::CONFIG.join(format!("config.{env}.toml")),
             dirs::CONFIG.join(format!("config.{env}.local.toml")),
@@ -729,27 +824,36 @@ pub fn global_config_files() -> Vec<PathBuf> {
         ];
         for f in global_profile_files {
             if f.is_file() {
-                config_files.push(f);
+                config_files.insert(f);
             }
         }
     }
+    *g = Some(config_files.clone());
     config_files
 }
 
-pub fn system_config_files() -> Vec<PathBuf> {
-    let mut config_files = vec![];
-    let system = dirs::SYSTEM.join("config.toml");
-    if system.is_file() {
-        config_files.push(system);
+pub fn system_config_files() -> IndexSet<PathBuf> {
+    let mut s = SYSTEM_CONFIG_FILES.lock().unwrap();
+    if let Some(s) = &*s {
+        return s.clone();
     }
+    let mut config_files = IndexSet::new();
+    if env::MISE_SYSTEM_CONFIG_FILE.is_file() {
+        config_files.insert(env::MISE_SYSTEM_CONFIG_FILE.clone());
+    }
+    let system_local = env::MISE_SYSTEM_CONFIG_FILE.with_extension("local.toml");
+    if system_local.is_file() {
+        config_files.insert(system_local);
+    }
+    *s = Some(config_files.clone());
     config_files
 }
 
 /// the top-most global config file or the path to where it should be written to
 pub fn global_config_path() -> PathBuf {
     global_config_files()
-        .into_iter()
-        .next_back()
+        .last()
+        .cloned()
         .unwrap_or_else(|| env::MISE_GLOBAL_CONFIG_FILE.clone())
 }
 
@@ -757,15 +861,20 @@ pub fn global_config_path() -> PathBuf {
 pub fn top_toml_config() -> Option<PathBuf> {
     load_config_paths(&TOML_CONFIG_FILENAMES, false)
         .iter()
-        .rev()
         .find(|p| p.to_string_lossy().ends_with(".toml"))
         .map(|p| p.to_path_buf())
 }
 
-/// list of all non-global mise.tomls
-pub fn local_toml_config_paths() -> Vec<PathBuf> {
-    load_config_paths(&DEFAULT_CONFIG_FILENAMES, false)
+pub static ALL_TOML_CONFIG_FILES: Lazy<IndexSet<PathBuf>> = Lazy::new(|| {
+    load_config_paths(&TOML_CONFIG_FILENAMES, false)
         .into_iter()
+        .collect()
+});
+
+/// list of all non-global mise.tomls
+pub fn local_toml_config_paths() -> Vec<&'static PathBuf> {
+    ALL_TOML_CONFIG_FILES
+        .iter()
         .filter(|p| !is_global_config(p))
         .collect()
 }
@@ -776,6 +885,7 @@ pub fn local_toml_config_path() -> PathBuf {
     local_toml_config_paths()
         .into_iter()
         .next_back()
+        .cloned()
         .unwrap_or_else(|| {
             dirs::CWD
                 .as_ref()
@@ -786,7 +896,7 @@ pub fn local_toml_config_path() -> PathBuf {
 
 fn load_all_config_files(
     config_filenames: &[PathBuf],
-    legacy_filenames: &BTreeMap<String, Vec<String>>,
+    idiomatic_filenames: &BTreeMap<String, Vec<String>>,
 ) -> Result<ConfigMap> {
     Ok(config_filenames
         .iter()
@@ -794,7 +904,7 @@ fn load_all_config_files(
         .collect_vec()
         .into_par_iter()
         .map(|f| {
-            let cf = parse_config_file(f, legacy_filenames).wrap_err_with(|| {
+            let cf = parse_config_file(f, idiomatic_filenames).wrap_err_with(|| {
                 format!(
                     "error parsing config file: {}",
                     style::ebold(display_path(f))
@@ -812,16 +922,16 @@ fn load_all_config_files(
 
 fn parse_config_file(
     f: &PathBuf,
-    legacy_filenames: &BTreeMap<String, Vec<String>>,
+    idiomatic_filenames: &BTreeMap<String, Vec<String>>,
 ) -> Result<Box<dyn ConfigFile>> {
-    match legacy_filenames.get(&f.file_name().unwrap().to_string_lossy().to_string()) {
+    match idiomatic_filenames.get(&f.file_name().unwrap().to_string_lossy().to_string()) {
         Some(plugin) => {
-            trace!("legacy version file: {}", display_path(f));
+            trace!("idiomatic version file: {}", display_path(f));
             let tools = backend::list()
                 .into_iter()
                 .filter(|f| plugin.contains(&f.to_string()))
                 .collect::<Vec<_>>();
-            LegacyVersionFile::parse(f.into(), tools).map(|f| Box::new(f) as Box<dyn ConfigFile>)
+            IdiomaticVersionFile::parse(f.into(), tools).map(|f| Box::new(f) as Box<dyn ConfigFile>)
         }
         None => config_file::parse(f),
     }
@@ -912,7 +1022,6 @@ fn default_task_includes() -> Vec<PathBuf> {
 }
 
 pub fn rebuild_shims_and_runtime_symlinks(new_versions: &[ToolVersion]) -> Result<()> {
-    install_state::reset();
     let config = Config::load()?;
     let ts = ToolsetBuilder::new().build(&config)?;
     trace!("rebuilding shims");
@@ -926,17 +1035,32 @@ pub fn rebuild_shims_and_runtime_symlinks(new_versions: &[ToolVersion]) -> Resul
     Ok(())
 }
 
+fn reset() {
+    if let Err(err) = timeout::run_with_timeout(
+        || {
+            install_state::reset();
+            backend::reset();
+            _CONFIG.write().unwrap().take();
+            *GLOBAL_CONFIG_FILES.lock().unwrap() = None;
+            *SYSTEM_CONFIG_FILES.lock().unwrap() = None;
+            GLOB_RESULTS.lock().unwrap().clear();
+            Ok(())
+        },
+        Duration::from_secs(5),
+    ) {
+        error!("reset: {err}");
+    }
+}
+
 #[cfg(test)]
+#[cfg(unix)]
 mod tests {
     use insta::assert_debug_snapshot;
 
-    use crate::test::reset;
-
     use super::*;
 
     #[test]
     fn test_load() {
-        reset();
         let config = Config::load().unwrap();
         assert_debug_snapshot!(config);
     }
