@@ -350,11 +350,11 @@ impl Backend for RubyPlugin {
         Ok(versions)
     }
 
-    fn legacy_filenames(&self) -> Result<Vec<String>> {
+    fn idiomatic_filenames(&self) -> Result<Vec<String>> {
         Ok(vec![".ruby-version".into(), "Gemfile".into()])
     }
 
-    fn parse_legacy_file(&self, path: &Path) -> Result<String> {
+    fn parse_idiomatic_file(&self, path: &Path) -> Result<String> {
         let v = match path.file_name() {
             Some(name) if name == "Gemfile" => parse_gemfile(&file::read_to_string(path)?),
             _ => {
@@ -369,11 +369,7 @@ impl Backend for RubyPlugin {
         Ok(v)
     }
 
-    fn install_version_impl(
-        &self,
-        ctx: &InstallContext,
-        tv: ToolVersion,
-    ) -> eyre::Result<ToolVersion> {
+    fn install_version_(&self, ctx: &InstallContext, tv: ToolVersion) -> eyre::Result<ToolVersion> {
         if let Err(err) = self.update_build_tool(Some(ctx)) {
             warn!("ruby build tool update error: {err:#}");
         }
@@ -442,13 +438,11 @@ fn parse_gemfile(body: &str) -> String {
 #[cfg(test)]
 mod tests {
     use super::*;
-    use crate::test::reset;
     use indoc::indoc;
     use pretty_assertions::assert_eq;
 
     #[test]
     fn test_parse_gemfile() {
-        reset();
         assert_eq!(
             parse_gemfile(indoc! {r#"
             ruby '2.7.2'
