@@ -33,8 +33,8 @@ pub enum Script {
     LatestStable,
     ListAliases,
     ListAll,
-    ListLegacyFilenames,
-    ParseLegacyFile(String),
+    ListIdiomaticFilenames,
+    ParseIdiomaticFile(String),
 
     // RuntimeVersion
     Download,
@@ -51,9 +51,9 @@ impl Display for Script {
             // Plugin
             Script::LatestStable => write!(f, "latest-stable"),
             Script::ListAll => write!(f, "list-all"),
-            Script::ListLegacyFilenames => write!(f, "list-legacy-filenames"),
+            Script::ListIdiomaticFilenames => write!(f, "list-legacy-filenames"),
             Script::ListAliases => write!(f, "list-aliases"),
-            Script::ParseLegacyFile(_) => write!(f, "parse-legacy-file"),
+            Script::ParseIdiomaticFile(_) => write!(f, "parse-legacy-file"),
             Script::Hook(script) => write!(f, "{script}"),
 
             // RuntimeVersion
@@ -137,7 +137,7 @@ impl ScriptManager {
 
     pub fn cmd(&self, script: &Script) -> Expression {
         let args = match script {
-            Script::ParseLegacyFile(filename) => vec![filename.clone()],
+            Script::ParseIdiomaticFile(filename) => vec![filename.clone()],
             Script::RunExternalCommand(_, args) => args.clone(),
             _ => vec![],
         };
@@ -187,13 +187,10 @@ mod tests {
     use pretty_assertions::assert_eq;
     use test_log::test;
 
-    use crate::test::reset;
-
     use super::*;
 
     #[test]
     fn test_script_manager() {
-        reset();
         let plugin_path = PathBuf::from("/tmp/asdf");
         let script_manager = ScriptManager::new(plugin_path.clone());
         assert_eq!(script_manager.plugin_path, plugin_path);
@@ -201,7 +198,6 @@ mod tests {
 
     #[test]
     fn test_get_script_path() {
-        reset();
         let plugin_path = PathBuf::from("/tmp/asdf");
         let script_manager = ScriptManager::new(plugin_path.clone());
 
