@@ -123,13 +123,12 @@ mod tests {
     use insta::assert_snapshot;
     use test_log::test;
 
-    use crate::test::{replace_path, reset};
+    use crate::test::replace_path;
 
     use super::*;
 
     #[test]
     fn test_hook_init() {
-        reset();
         let nushell = Nushell::default();
         let exe = Path::new("/some/dir/mise");
         assert_snapshot!(nushell.activate(exe, " --status".into()));
@@ -137,26 +136,22 @@ mod tests {
 
     #[test]
     fn test_set_env() {
-        reset();
         assert_snapshot!(Nushell::default().set_env("FOO", "1"));
     }
 
     #[test]
     fn test_prepend_env() {
-        reset();
         let sh = Nushell::default();
         assert_snapshot!(replace_path(&sh.prepend_env("PATH", "/some/dir:/2/dir")));
     }
 
     #[test]
     fn test_unset_env() {
-        reset();
         assert_snapshot!(Nushell::default().unset_env("FOO"));
     }
 
     #[test]
     fn test_deactivate() {
-        reset();
         let deactivate = Nushell::default().deactivate();
         assert_snapshot!(replace_path(&deactivate));
     }
